package data;

import java.util.ArrayList;

import utility.SequenceMaker;
import biology.Sequence;

public class OperationSequence {

	private Sequence randomSequence;
	private Sequence outputSequence;

	/* one OperationSequence constists of several different sequence type: promoter, signal, switcher, ...
	 *  - the complete sequence of one OperationSequence will be made up by putting together all entries in subSequences
	 *  - the i-th entry of nameOfSubSequence will describe what type of subSeqence the i-th entry in subSequences is
	 */
	private ArrayList<Sequence> subSequences;
	private ArrayList<String> nameOfSubSequence;


	public OperationSequence() {
		subSequences = new ArrayList<Sequence>();
		nameOfSubSequence = new ArrayList<String>();
		randomSequence = SequenceMaker.createDNASequence(Sequence.FIVE_TO_THREE, SequenceMaker.STANDARD_DIFFERENCE, SequenceMaker.STANDARD_LENGTH);
		outputSequence = randomSequence;
	}
	public OperationSequence(Sequence randomSequence) {
		subSequences = new ArrayList<Sequence>();
		nameOfSubSequence = new ArrayList<String>();
		this.randomSequence = randomSequence;
		outputSequence = randomSequence;
	}

	public void empty() {
		subSequences.clear();
		nameOfSubSequence.clear();
	}

	public void addSubSequence(Sequence s, String name) {
		subSequences.add(subSequences.size(), s);
		nameOfSubSequence.add(nameOfSubSequence.size(), name);
	}


	public String toString() {
		String result = "";
		for (Sequence s : subSequences) {
			result = result + s.getDNASequence(Sequence.FIVE_TO_THREE);
		}
		return result;
	}

	public Sequence getCompleteSequence() {
		return new Sequence(toString(), Sequence.FIVE_TO_THREE, Sequence.TYPE_DNA);
	}
	public int getNumberOfSubSequences() {
		return subSequences.size();
	}
	public ArrayList<Sequence> getSubSequences() {
		return subSequences;
	}
	public ArrayList<String> getNameOfSubSequence() {
		return nameOfSubSequence;
	}
	public Sequence getOutput() {
		return outputSequence;
	}

}
